import { Component, OnInit } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CapabilityLauncherService } from './services/capability-launcher.service';
import { CapabilityRequest } from './model/capability-request';
import { CapabilityExecution } from './model/capability-execution';

@Component({
  selector: 'app-workspaces',
  templateUrl: './workspaces.component.html',
  styleUrls: ['./workspaces.component.scss'],
})
export class WorkspacesComponent implements OnInit {
  public capabilityRequests: Array<CapabilityRequest> = [];
  public capabilityExecutions: Array<CapabilityExecution> = [];

  public productLocator: string;
  public userEmail: string;

  constructor(private capabilityLauncher: CapabilityLauncherService) {
    // this is the famous 394 MB 13B-014 execblock, a useful smallish test
    this.productLocator = "uid://evla/execblock/27561b56-4c6a-4614-bc26-67e436b5e92c";
    this.userEmail = null;
  }

  ngOnInit(): void {}

  /**
   * OnClick method that creates a capability request for the null capability and submits it
   */
  nullButtonOnClick(): void {
    this.launchCapability('null', '-g');
  }

  /**
   * OnClick method that creates a capability request for the test_download capability and submits it
   */
  downloadButtonOnClick(): void {
    this.launchCapability(
      'test_download',
      {'product_locator': this.productLocator, 'user_email': this.userEmail}
    );
  }

  /**
   * method that sets the user input Science Product Locator for the download capability
   * @param spl the Science Product Locator to download
   */
  setProductLocator(spl: string){
    this.productLocator = spl;
  }

  /**
   * method to set the user email for notifications
   * @param email user specified email
   */
  setUserEmail(email: string){
    this.userEmail = email;
  }

  /**
   * Method that uses the capabilityLauncher service to launch a capability
   * @param capabilityName  Name of capability
   * @param parameters      Parameters of capability request
   * @param email           User email for notifications (Optional)
   */
  launchCapability(capabilityName: string, parameters: any): void {
    // Create capability request
    this.capabilityLauncher.createRequest(capabilityName, parameters).subscribe(
      (requestResponse) => {
        this.capabilityRequests.push(requestResponse);
        if (requestResponse.id) {
          // Capability request created; ID found
          // Submit capability request
          this.capabilityLauncher
            .submit(capabilityName, requestResponse.id)
            .subscribe(
              (submitResponse) => {
                this.capabilityExecutions.push(submitResponse);
              },
              (error) => {
                console.log(error);
              }
            );
        }
      },
      (error) => {
        console.log(error);
      }
    );
  }
}
